==> v1.0.tar.gz: codeigniter4cms/app/Views/delProductForm.php <==
<?= $this->extend('layout') ?>
<?= $this->section('content') ?>


<div class ="flex2">
	<div class ="content">
			<div class="d-flex justify-content-center">
            <?= form_open_multipart('editProductDo'); ?>
			
			
			<div class="form-group"> 
			<label for="title">Brief Product Description(title of product)</label>
			 <input type="input" name="title" id ="title" class="form-control"  value= "<?php echo $product['imageTitle'] ;?>"      /><br />
			 </div>
    
            <div class="form-group"> 
			<label for="category">Select category For product</label>	
			<select id="category" name="category">
			<option value="FToner">Toner n Cleanser</option>
			<option value="FExfoliate">Face Exfoliate</option>
			<option value="FMask">Face Mask</option>
			<option value="Boys"></option>
			<option value="Girls"></option>
			<option value="Baby"></option>
			<option value="Accessory"></option>
			</select> 
			</div><!-- end form group for select-->
			  
	         <div class = "form-group">
	          <label for="price">Price Numbers only</label> 
	          <input type="input" name="price" id ="price" class="form-control" value = "<?php echo $product['price'] ;?>"  /><br />
	         </div>
			   
	    
	         <div class="form-group"> 
			 <label for="info">Full Product Details </label> 
			 <textarea class="form-control" id ="prodInfo" rows="8" cols ="50" name ="info" required ="true"  ><?php echo $product['info'] ;?></textarea>
			 </div>
			 
	    
	    
	    
				<div class="form-group"> 
			    <input type="hidden" name="Id" value="<?php echo $product['Id'];?>" />
			    
			    </div>
	    
	    
	    
			    <div class="form-group"> 
			   <input type="submit" class ="btn-success" value="submit" />
			   </div>
                           
			   
			   <div class="form-group"> 
			 <h1 style ="color:red";>  <?php echo $info ;?></h1>
			   </div>
			   
			   <div class="form-group"> 
			  <div class="item"><?php echo "<img class = \"img-fluid \" src =".base_url('productImages')."/".$product['image'];?>   </div>
			   </div>
			   
			   
		   <?php echo form_close();?>

	</div><!--end div class flex d-->
	
	
	</div><!-- content end-->
</div><!-- flex end-->
<?= $this->endSection() ?>

==> 1.1.tar.gz: codeigniter4cms/app/Views/delProductForm.php <==
<?= $this->extend('layout') ?>
<?= $this->section('content') ?>


<div class ="flex2">
	<div class ="content">
			<div class="d-flex justify-content-center">
            <?= form_open_multipart('editProductDo'); ?>
			<?= csrf_field() ?>
			
			<div class="form-group"> 
			<label for="title">Brief Product Description(title of product)</label>
			 <input type="input" name="title" id ="title" class="form-control"  value= "<?php echo $product['imageTitle'] ;?>"      /><br />
			 </div>
    
            <div class="form-group"> 
			<label for="category">Select category For product</label>	
			<select id="category" name="category">
			<option value="FMens">Mens</option>
			<option value="FLadies">Ladies</option>
						<option value="FAccessories">Accessories</option>
			</select> 
			</div><!-- end form group for select-->
			  
	         <div class = "form-group">
	          <label for="price">Price Numbers only</label> 
	          <input type="input" name="price" id ="price" class="form-control" value = "<?php echo $product['price'] ;?>"  /><br />
	         </div>
			   
	    
	         <div class="form-group"> 
			 <label for="info">Full Product Details </label> 
			 <textarea class="form-control" id ="prodInfo" rows="8" cols ="50" name ="info" required ="true"  ><?php echo $product['info'] ;?></textarea>
			 </div>
			 
	    
	    
	    
				<div class="form-group"> 
			    <input type="hidden" name="Id" value="<?php echo $product['Id'];?>" />
			    
			    </div>
	    
	    
	    
			    <div class="form-group"> 
			   <input type="submit" class ="btn-success" value="submit" />
			   </div>
                           
			   
			   <div class="form-group"> 
			 <h1 style ="color:red";>  <?php echo $info ;?></h1>
			   </div>
			   
			   <div class="form-group"> 
			  <div class="item"><?php echo "<img class = \"img-fluid \" src =".base_url('productImages')."/".$product['image'];?>   </div>
			   </div>
			   
			   
		   <?php echo form_close();?>

	</div><!--end div class flex d-->
	
	
	</div><!-- content end-->
</div><!-- flex end-->
<?= $this->endSection() ?>
